Index: trunk/AddOn/TAcq/brproc.h
===================================================================
--- trunk/AddOn/TAcq/brproc.h	(revision 3656)
+++ trunk/AddOn/TAcq/brproc.h	(revision 3683)
@@ -1,19 +1,21 @@
-#ifndef  BRPROCA_H_SEEN
-#define  BRPROCA_H_SEEN
+#ifndef  BRPROC_H_SEEN
+#define  BRPROC_H_SEEN
 
 //----------------------------------------------------------------
-// ---- classe de thread de traitememt  acquisition BAORadio -----
-// LAL -      R. Ansari - Juin/Juillet 2008 
+// Projet BAORadio - (C) LAL/IRFU  2008-2010
+// Classes de threads de traitememt donnees BAORadio 
 //----------------------------------------------------------------
 
 
-#include "racqumem.h"
 #include <string>
 #include <vector>
 #include <iostream>
+
+#include "racqumem.h"
+#include "brbaseproc.h"
 #include "sopnamsp.h"
-#include "zthread.h"
-
-#include "brtypes.h"
+#include "tvector.h"
+#include "ntuple.h"
+#include "datatable.h"
 
 using namespace std;
@@ -21,5 +23,30 @@
 
 //---------------------------------------------------------------------
-// Classe thread de traitement avec 2 voies par frame (donnees brutes)
+// Classe de traitement - calcul de visibilite pour n fibres 
+//---------------------------------------------------------------------
+class BRVisibilityCalculator : public BRBaseProcessor {
+public:	
+  BRVisibilityCalculator(RAcqMemZoneMgr& memgr, string outpath, uint_4 nmean=1000, 
+			 uint_4 freq1=0, uint_4 freq2=0, uint_4 nbfreq=1);
+  virtual ~BRVisibilityCalculator(); // Fait le nettoyage final , sauvegarde des objets ...
+
+  virtual int Process(); 
+protected:
+  uint_4 nmean_;  // Nombre de spectres pour le calcul des moyennes 
+  string outpath_;  // directory pour fichiers de sortie
+  uint_4 numfreq1_,numfreq2_,nbinfreq_;
+  vector<uint_8> vframecount_;
+  vector<uint_8> vtimetag_;
+  vector<uint_8> vnpaqm_;
+
+};
+
+
+//-------------------------------------------------------------------------
+//    **** OBSOLETE : BRProcA2C et BRProcB4C
+//   Anciennes classes de traitement (Avant Nov2009) utilises par mcrd.cc
+//-------------------------------------------------------------------------
+//---------------------------------------------------------------------
+// Classe thread de traitement avec 2 voies par frame (donnees raw/FFT
 //---------------------------------------------------------------------
 
@@ -35,9 +62,9 @@
   o card : numero de carte , juste pour les impressions 
 */
-class BRProcARaw2C : public ZThread {
+class BRProcA2C : public ZThread {
 public:	
-  BRProcARaw2C(RAcqMemZoneMgr& mem, string& path, uint_4 nmean=10, 
-               uint_4 nmax=100, bool fgtshist=false, uint_4 nfsmap=0, 
-               bool fgnotrl=false, int card=1);
+  BRProcA2C(RAcqMemZoneMgr& mem, string& path, bool fgraw, 
+	    uint_4 nmean=10, uint_4 nmax=100, bool fgtshist=false, 
+	    uint_4 nfsmap=0, bool fgnotrl=false, int card=1);
   virtual void run(); 
   void Stop();
@@ -46,4 +73,5 @@
   RAcqMemZoneMgr& memgr;
   bool stop_;  
+  bool fgraw_;   // true -> raw data 
   uint_4 nmax_;  // Nombre maxi de blocs MemZone traites
   uint_4 nmean_;  // Nombre de spectres pour le calcul des moyennes 
@@ -56,5 +84,5 @@
 
 //---------------------------------------------------------------------
 // Classe thread de traitement 2 x 2 voies/frames (Apres BRProcARaw2C)
 //---------------------------------------------------------------------
 /*-- Arguments du constructeur : 
@@ -67,8 +95,8 @@
 */
 
-class BRProcBRaw4C : public ZThread {
+class BRProcB4C : public ZThread {
 public:	
-  BRProcBRaw4C(RAcqMemZoneMgr& mem1, RAcqMemZoneMgr& mem2, string& path, 
-               uint_4 nmean=10, uint_4 nmax=100, bool fgnotrl=false);
+  BRProcB4C(RAcqMemZoneMgr& mem1, RAcqMemZoneMgr& mem2, string& path, 
+	    bool fgraw, uint_4 nmean=10, uint_4 nmax=100, bool fgnotrl=false);
   virtual void run(); 
   void Stop();
@@ -78,4 +106,5 @@
   RAcqMemZoneMgr& memgr2;
   bool stop_;  
+  bool fgraw_;   // true -> raw data 
   uint_4 nmax_;  // Nombre maxi de blocs MemZone traites
   uint_4 nmean_;  // Nombre de blocs pour le calcul des moyennes 
@@ -56,5 +84,5 @@
 
 //---------------------------------------------------------------------
-// Classe thread de traitement 2 x 2 voies/frames (Apres BRProcARaw2C)
+// Classe thread de traitement 2 x 2 voies/paquet (Apres BRProcA2C)
 //---------------------------------------------------------------------
 /*-- Arguments du constructeur : 
